==> gcc-4.2.3.tar.gz: gcc-4.2.3/libstdc++-v3/testsuite/util/io/prog_bar.cc <==
// -*- C++ -*-

// Copyright (C) 2005, 2006 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the terms
// of the GNU General Public License as published by the Free Software
// Foundation; either version 2, or (at your option) any later
// version.

// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this library; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// As a special exception, you may use this file as part of a free
// software library without restriction.  Specifically, if other files
// instantiate templates or use macros or inline functions from this
// file, or you compile this file and link it with other files to
// produce an executable, this file does not by itself cause the
// resulting executable to be covered by the GNU General Public
// License.  This exception does not however invalidate any other
// reasons why the executable file might be covered by the GNU General
// Public License.

// Copyright (C) 2004 Ami Tavory and Vladimir Dreizin, IBM-HRL.

// Permission to use, copy, modify, sell, and distribute this software
// is hereby granted without fee, provided that the above copyright
// notice appears in all copies, and that both that copyright notice
// and this permission notice appear in supporting documentation. None
// of the above authors, nor IBM Haifa Research Laboratories, make any
// representation about the suitability of this software for any
// purpose. It is provided "as is" without express or implied
// warranty.

/**
 * @file prog_bar.cpp
 * Contains a progress bar - idea taken from boost::timer by Beman Dawes.
 */

#include <util/io/prog_bar.hpp>

namespace pb_ds
{

  namespace test
  {

    prog_bar::
    prog_bar(size_t max, std::ostream& r_os, bool display/*= true*/) :
      m_cur(0),
      m_max(max),
      m_cur_disp(0),
      m_r_os(r_os),
      m_display(display)
    {
      if (m_display == false)
        return;

      for (std::size_t i = 0; i < num_disp; ++i)
        m_r_os << "-";

      m_r_os << std::endl;
    }

    void
    prog_bar::
    inc()
    {
      ++m_cur;

      if (m_display == false)
        return;

      while (m_cur*  num_disp >= m_max*  m_cur_disp&&  m_cur_disp < num_disp)
	{
	  m_r_os << '*';
	  m_r_os.flush();

	  ++m_cur_disp;
	}
    }

  } // namespace test

} // namespace pb_ds

==> gcc-5_5.4.1.orig.tar.gz: gcc-5.4.0/libstdc++-v3/testsuite/util/io/prog_bar.cc <==
// -*- C++ -*-

// Copyright (C) 2005-2015 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the terms
// of the GNU General Public License as published by the Free Software
// Foundation; either version 3, or (at your option) any later
// version.

// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.


// Copyright (C) 2004 Ami Tavory and Vladimir Dreizin, IBM-HRL.

// Permission to use, copy, modify, sell, and distribute this software
// is hereby granted without fee, provided that the above copyright
// notice appears in all copies, and that both that copyright notice
// and this permission notice appear in supporting documentation. None
// of the above authors, nor IBM Haifa Research Laboratories, make any
// representation about the suitability of this software for any
// purpose. It is provided "as is" without express or implied
// warranty.

/**
 * @file prog_bar.cpp
 * Contains a progress bar - idea taken from boost::timer by Beman Dawes.
 */

#include <util/io/prog_bar.hpp>

namespace __gnu_pbds
{
  namespace test
  {
    prog_bar::
    prog_bar(std::size_t max, std::ostream& r_os, bool display/*= true*/) :
      m_cur(0),
      m_max(max),
      m_cur_disp(0),
      m_r_os(r_os),
      m_display(display)
    {
      if (m_display == false)
        return;

      for (std::size_t i = 0; i < num_disp; ++i)
        m_r_os << "-";

      m_r_os << std::endl;
    }

    void
    prog_bar::
    inc()
    {
      ++m_cur;

      if (m_display == false)
        return;

      while (m_cur * num_disp >= m_max * m_cur_disp && m_cur_disp < num_disp)
	{
	  m_r_os << '*';
	  m_r_os.flush();
	  ++m_cur_disp;
	}
    }

  } // namespace test

} // namespace __gnu_pbds
